package net.cattaka.rdbassistant.sqlite;

import java.sql.Connection;
import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import net.cattaka.rdbassistant.RdbaConfigConstants;
import net.cattaka.rdbassistant.config.RdbaConnectionInfo;
import net.cattaka.rdbassistant.config.RdbaJdbcBundle;
import net.cattaka.rdbassistant.core.RdbaException;
import net.cattaka.rdbassistant.core.RdbaConnection;
import net.cattaka.rdbassistant.gui.connectioninfo.RdbaConnectionInfoEditor;

public class SqliteRdbaConnectionInfo implements RdbaConnectionInfo {
	private static final long serialVersionUID = 1L;
	
	private String label = "";
	private String database = "";
	
	public String toUrl() {
		return String.format("jdbc:sqlite:%s", database);
	}
	
	public RdbaConnection createConnection(RdbaJdbcBundle rdbaJdbcBundle) throws RdbaException {
		Driver driver = null;
		driver = rdbaJdbcBundle.getDriver(RdbaConfigConstants.DRIVER_JDBC_SQLITE, "org.sqlite.JDBC");
		
		Connection conn = null;
		try {
			Properties info = new Properties();
			conn = driver.connect(toUrl(), info);
			conn.setAutoCommit(false);
		} catch (SQLException e) {
			throw new RdbaException(e.getMessage(),e);
		}
		
		SqliteRdbaConnection rdbaConnection = new SqliteRdbaConnection(conn, "main");
		
		return rdbaConnection;
	}

	public String[] getDisplayStrings() {
		return new String[]{"SQLite",label, database,""};
	}

	public String getTooltipText() {
		return String.format("%s", database);
	}

	public RdbaConnectionInfoEditor createEditor() {
		return new SqliteRdbaConnectionInfoEditor();
	}

	public String[] toStringArray() {
		String[] result = {
			getClass().getCanonicalName(),
			"2",
			label,
			database
		};
		return result;
	}
	
	public boolean restoreStringArray(String[] stringArray, int configRevision) {
		boolean result = false;
		if (stringArray[1].equals("1")) {
			result = false;
		} else if (stringArray[1].equals("2") && stringArray.length == 4) {
			label = stringArray[2];
			database = stringArray[3];
			result = true;
		}
		return result;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public String getDatabase() {
		return database;
	}

	public void setDatabase(String database) {
		this.database = database;
	}
}
